SWDEV:253548 : remove gfx-arch macros
Change-Id: I1ef0b4e080c15a9c6228f48ecd6a65b134d0a72d
Этот коммит содержится в:
коммит произвёл
Sarbojit Sarkar
родитель
c7ac5531d3
Коммит
a2f9a2d469
@@ -29,13 +29,6 @@ THE SOFTWARE.
|
||||
#include "hip/hip_runtime.h"
|
||||
#include "test_common.h"
|
||||
|
||||
#if __HIP_ARCH_GFX803__ || \
|
||||
__HIP_ARCH_GFX900__ || \
|
||||
__HIP_ARCH_GFX906__ || \
|
||||
__HIP_ARCH_GFX908__ || \
|
||||
__HIP_ARCH_GFX1010__ || \
|
||||
__HIP_ARCH_GFX1012__
|
||||
|
||||
__global__ void kernel_abs_int64(long long *input, long long *output) {
|
||||
int tx = threadIdx.x;
|
||||
output[tx] = abs(input[tx]);
|
||||
@@ -46,8 +39,6 @@ __global__ void kernel_lgamma_double(double *input, double *output) {
|
||||
output[tx] = lgamma(input[tx]);
|
||||
}
|
||||
|
||||
#endif
|
||||
|
||||
#define CHECK_LGAMMA_DOUBLE(IN, OUT, EXP) \
|
||||
{ \
|
||||
if (OUT != EXP) { \
|
||||
|
||||
Ссылка в новой задаче
Block a user